==> jc-1.4.0.tar.gz: java/io/PipedReader.h <==
// public class java.io.PipedReader

// class file dependencies
// @dep_class 64f43be4fefefe06 java_io_PipedReader
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_Reader

#include "java/io/Reader.h"

#ifndef _JC_java_io_PipedReader_H_
#define _JC_java_io_PipedReader_H_

// Forward structure declarations
struct _jc_java_io_PipedWriter$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_PipedReader$sub_refs	_jc_java_io_PipedReader$sub_refs;
typedef struct _jc_java_io_PipedReader$sub_nonrefs	_jc_java_io_PipedReader$sub_nonrefs;
typedef struct _jc_java_io_PipedReader$refs	_jc_java_io_PipedReader$refs;
typedef struct _jc_java_io_PipedReader$nonrefs	_jc_java_io_PipedReader$nonrefs;
typedef struct _jc_java_io_PipedReader$object	_jc_java_io_PipedReader$object;

typedef struct _jc_java_io_PipedReader$fields_struct	_jc_java_io_PipedReader$fields_struct;
typedef const struct _jc_java_io_PipedReader$vmethods	_jc_java_io_PipedReader$vmethods;
typedef const struct _jc_java_io_PipedReader$vtable	_jc_java_io_PipedReader$vtable;
typedef const struct _jc_java_io_PipedReader$vtype	_jc_java_io_PipedReader$vtype;

// Class fields structure
struct _jc_java_io_PipedReader$fields_struct {
	jint	PIPE__5fSIZE;
};
extern _jc_java_io_PipedReader$fields_struct _jc_java_io_PipedReader$class_fields;

// Constructors
extern void _jc_java_io_PipedReader$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_PipedReader$object *);
extern void _jc_java_io_PipedReader$method$_init$0cb167cb7cfbbc43(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_java_io_PipedWriter$object *);

// Virtual methods
extern void _jc_java_io_PipedReader$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_PipedReader$object *);
extern void _jc_java_io_PipedReader$method$connect$95fe4eda9e9fcf66(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_java_io_PipedWriter$object *);
extern jint _jc_java_io_PipedReader$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_PipedReader$object *);
extern jint _jc_java_io_PipedReader$method$read$146ad4b836c4a55b(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_char_array *, jint, jint);
extern jboolean _jc_java_io_PipedReader$method$ready$83ea616797d9c364(_jc_env *, struct _jc_java_io_PipedReader$object *);
extern void _jc_java_io_PipedReader$method$receive$147ab5152398659a(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_char_array *, jint, jint);
extern void _jc_java_io_PipedReader$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_io_PipedReader$object *);

// Virtual method descriptors
extern _jc_method _jc_java_io_PipedReader$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_PipedReader$method_info$connect$95fe4eda9e9fcf66;
extern _jc_method _jc_java_io_PipedReader$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_PipedReader$method_info$read$146ad4b836c4a55b;
extern _jc_method _jc_java_io_PipedReader$method_info$ready$83ea616797d9c364;
extern _jc_method _jc_java_io_PipedReader$method_info$receive$147ab5152398659a;
extern _jc_method _jc_java_io_PipedReader$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_io_PipedReader$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_PipedReader$object *);
	void	(*connect$95fe4eda9e9fcf66)(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_java_io_PipedWriter$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_PipedReader$object *);
	jint	(*read$146ad4b836c4a55b)(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_char_array *, jint, jint);
	jboolean	(*ready$83ea616797d9c364)(_jc_env *, struct _jc_java_io_PipedReader$object *);
	void	(*receive$147ab5152398659a)(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_char_array *, jint, jint);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_io_PipedReader$object *);
};

// Vtable
struct _jc_java_io_PipedReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_java_io_PipedReader$vmethods	java_io_PipedReader;
};

// Vtype
struct _jc_java_io_PipedReader$vtype {
	_jc_type			type;
	_jc_java_io_PipedReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_PipedReader$sub_refs {
	struct _jc_java_io_PipedWriter$object	*source;
	_jc_char_array	*buffer;
	_jc_char_array	*read__5fbuf;
};

// Reference instance fields (object)
struct _jc_java_io_PipedReader$refs {
    _jc_java_io_PipedReader$sub_refs	java_io_PipedReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_PipedReader$sub_nonrefs {
	jboolean	closed;
	jint	in;
	jint	out;
};

// Non-reference instance fields (object)
struct _jc_java_io_PipedReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_java_io_PipedReader$sub_nonrefs	java_io_PipedReader;
};

// Object instance structure
struct _jc_java_io_PipedReader$object {
	_jc_java_io_PipedReader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_PipedReader$vtype	*vtype;
	_jc_java_io_PipedReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_PipedReader$vtype _jc_java_io_PipedReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_PipedReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_PipedReader$class_object;

#endif	/* _JC_java_io_PipedReader_H_ */

==> jc-1.4.6.tar.gz: java/io/PipedReader.h <==
// public class java.io.PipedReader

// class file dependencies
// @dep_class 64f43be4fefefe06 java_io_PipedReader
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_Reader

#include "java/io/Reader.h"

#ifndef _JC_java_io_PipedReader_H_
#define _JC_java_io_PipedReader_H_

// Forward structure declarations
struct _jc_java_io_PipedWriter$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_PipedReader$sub_refs	_jc_java_io_PipedReader$sub_refs;
typedef struct _jc_java_io_PipedReader$sub_nonrefs	_jc_java_io_PipedReader$sub_nonrefs;
typedef struct _jc_java_io_PipedReader$refs	_jc_java_io_PipedReader$refs;
typedef struct _jc_java_io_PipedReader$nonrefs	_jc_java_io_PipedReader$nonrefs;
typedef struct _jc_java_io_PipedReader$object	_jc_java_io_PipedReader$object;

typedef struct _jc_java_io_PipedReader$fields_struct	_jc_java_io_PipedReader$fields_struct;
typedef const struct _jc_java_io_PipedReader$vmethods	_jc_java_io_PipedReader$vmethods;
typedef const struct _jc_java_io_PipedReader$vtable	_jc_java_io_PipedReader$vtable;
typedef const struct _jc_java_io_PipedReader$vtype	_jc_java_io_PipedReader$vtype;

// Class fields structure
struct _jc_java_io_PipedReader$fields_struct {
	jint	PIPE__5fSIZE;
};
extern _jc_java_io_PipedReader$fields_struct _jc_java_io_PipedReader$class_fields;

// Constructors
extern void _jc_java_io_PipedReader$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_PipedReader$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedReader$method$_init$0cb167cb7cfbbc43(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_java_io_PipedWriter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_io_PipedReader$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_PipedReader$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedReader$method$connect$95fe4eda9e9fcf66(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_java_io_PipedWriter$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_PipedReader$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_PipedReader$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_PipedReader$method$read$146ad4b836c4a55b(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_io_PipedReader$method$ready$83ea616797d9c364(_jc_env *, struct _jc_java_io_PipedReader$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedReader$method$receive$147ab5152398659a(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedReader$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_io_PipedReader$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_PipedReader$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_PipedReader$method_info$connect$95fe4eda9e9fcf66;
extern _jc_method _jc_java_io_PipedReader$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_PipedReader$method_info$read$146ad4b836c4a55b;
extern _jc_method _jc_java_io_PipedReader$method_info$ready$83ea616797d9c364;
extern _jc_method _jc_java_io_PipedReader$method_info$receive$147ab5152398659a;
extern _jc_method _jc_java_io_PipedReader$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_io_PipedReader$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_PipedReader$object *) _JC_JCNI_ATTR;
	void	(*connect$95fe4eda9e9fcf66)(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_java_io_PipedWriter$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_PipedReader$object *) _JC_JCNI_ATTR;
	jint	(*read$146ad4b836c4a55b)(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
	jboolean	(*ready$83ea616797d9c364)(_jc_env *, struct _jc_java_io_PipedReader$object *) _JC_JCNI_ATTR;
	void	(*receive$147ab5152398659a)(_jc_env *, struct _jc_java_io_PipedReader$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_io_PipedReader$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_PipedReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_java_io_PipedReader$vmethods	java_io_PipedReader;
};

// Vtype
struct _jc_java_io_PipedReader$vtype {
	_jc_type			type;
	_jc_java_io_PipedReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_PipedReader$sub_refs {
	struct _jc_java_io_PipedWriter$object	*source;
	_jc_char_array	*buffer;
	_jc_char_array	*read__5fbuf;
};

// Reference instance fields (object)
struct _jc_java_io_PipedReader$refs {
    _jc_java_io_PipedReader$sub_refs	java_io_PipedReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_PipedReader$sub_nonrefs {
	jboolean	closed;
	jint	in;
	jint	out;
};

// Non-reference instance fields (object)
struct _jc_java_io_PipedReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_java_io_PipedReader$sub_nonrefs	java_io_PipedReader;
};

// Object instance structure
struct _jc_java_io_PipedReader$object {
	_jc_java_io_PipedReader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_PipedReader$vtype	*vtype;
	_jc_java_io_PipedReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_PipedReader$vtype _jc_java_io_PipedReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_PipedReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_PipedReader$class_object;

#endif	/* _JC_java_io_PipedReader_H_ */
